# Aitana: access volcano data

Aitana (named after the great football midfielder 
[Aitana Bonmati](https://en.wikipedia.org/wiki/Aitana_Bonmat%C3%AD)) is a project to facilitate access to different types of volcano data. 

It currently only provides methods to access data from the New Zealand
volcanoes [Ruapehu](https://volcano.si.edu/volcano.cfm?vn=241100) and [Whakaari/White Island](https://volcano.si.edu/volcano.cfm?vn=241040).

## Dependencies
* pandas
* requests
* matplotlib
* statsmodels

## Installation

```
pip install -U aitana
```

## Documentation

Learn more about aitana in its official [documentation](https://tsc-tools.github.io/aitana/)
Try out a [Jupyter notebook](https://github.com/tsc-tools/aitana/blob/main/docs/aitana_example.ipynb)

## Get in touch

Report bugs, suggest features, view the source code, and ask questions [on GitHub](https://github.com/tsc-tools/aitana/issues).
